@@ -75,6 +75,56 @@ geocode <- function(enderecos,
                     cache = TRUE,
                     n_cores = 1 ){
 
+
+  # ## ---- tiny timing toolkit (self-contained) ------------------------------
+  # .make_timer <- function(verbose = TRUE) {
+  #   .marks <- list()
+  #   .t0_rt  <- proc.time()[["elapsed"]]     # monotonic wall clock
+  #   .t_prev <- .t0_rt
+  #
+  #   fmt <- function(secs) sprintf("%.3f s", secs)
+  #
+  #   mark <- function(label) {
+  #     now <- proc.time()[["elapsed"]]
+  #     step  <- now - .t_prev
+  #     total <- now - .t0_rt
+  #     .marks <<- append(.marks, list(list(label = label, step = step, total = total)))
+  #     .t_prev <<- now
+  #     if (verbose) message(sprintf("[%s] +%s (total %s)", label, fmt(step), fmt(total)))
+  #     invisible(now)
+  #   }
+  #
+  #   summary <- function(print_summary = verbose) {
+  #     if (length(.marks) == 0) return(invisible(data.frame()))
+  #     df <- data.frame(
+  #       step = vapply(.marks, `[[`, "", "label"),
+  #       step_sec = vapply(.marks, `[[`, 0.0, "step"),
+  #       total_sec = vapply(.marks, `[[`, 0.0, "total"),
+  #       stringsAsFactors = FALSE
+  #     ) |>
+  #       dplyr::mutate(step_relative = round(step_sec / max(total_sec)*100, 1))
+  #
+  #     if (print_summary) {
+  #       message("— Timing summary —")
+  #       print(df, row.names = FALSE)
+  #     }
+  #     df
+  #   }
+  #
+  #   time_it <- function(label, expr) {
+  #     force(label)
+  #     res <- eval.parent(substitute(expr))
+  #     mark(label)
+  #     invisible(res)
+  #   }
+  #
+  #   list(mark = mark, summary = summary, time_it = time_it)
+  # }
+  # timer <- .make_timer(verbose = isTRUE(verboso))
+  # on.exit(timer$summary(), add = TRUE)
+  # ## -----------------------------------------------------------------------
+
+
   # check input
   checkmate::assert_data_frame(enderecos)
   checkmate::assert_logical(resultado_completo, any.missing = FALSE, len = 1)
@@ -83,7 +133,7 @@ geocode <- function(enderecos,
   checkmate::assert_logical(verboso, any.missing = FALSE, len = 1)
   checkmate::assert_logical(cache, any.missing = FALSE, len = 1)
   checkmate::assert_number(n_cores, lower = 1, finite = TRUE)
-  checkmate::assert_number(h3_res, null.ok = TRUE, lower = 0, upper = 15)
+  checkmate::assert_numeric(h3_res, null.ok = TRUE, lower = 0, upper = 15, max.len = 16)
   campos_endereco <- assert_and_assign_address_fields(
     campos_endereco,
     enderecos
@@ -96,6 +146,10 @@ geocode <- function(enderecos,
 
   if (verboso) message_standardizing_addresses()
 
+  # systime start 66666 ----------------
+  # timer$mark("Start")
+
+
   input_padrao <- enderecobr::padronizar_enderecos(
     enderecos,
     campos_do_endereco = enderecobr::correspondencia_campos(
@@ -124,6 +178,10 @@ geocode <- function(enderecos,
     )
   }
 
+  # systime padronizacao 66666 ----------------
+  # timer$mark("Padronizacao")
+
+
   # create temp id
   data.table::setDT(enderecos)[, tempidgeocodebr := 1:nrow(input_padrao) ]
   input_padrao[, tempidgeocodebr := 1:nrow(input_padrao) ]
@@ -151,6 +209,20 @@ geocode <- function(enderecos,
                          overwrite = TRUE, temporary = TRUE)
 
 
+  # systime register standardized 66666 ----------------
+  # timer$mark("Register standardized input")
+
+
+  # cria coluna "log_causa_confusao" identificando logradouros que geram confusao
+  # issue https://github.com/ipeaGIT/geocodebr/issues/67
+  cria_col_logradouro_confusao(con)
+
+  # systime cria coluna "log_causa_confusao 66666 ----------------
+  # timer$mark("Cria coluna log_causa_confusao")
+
+
+
+
   # create an empty output table that will be populated -----------------------------------------------
 
   # Define schema
@@ -162,7 +234,9 @@ geocode <- function(enderecos,
     logradouro_encontrado = arrow::string(),
     tipo_resultado = arrow::string(),
     contagem_cnefe = arrow::int32(),
-    desvio_metros = arrow::int32()
+    desvio_metros = arrow::int32(),
+    log_causa_confusao = arrow::boolean(),
+    similaridade_logradouro = arrow::float16()
 
   )
 
@@ -177,6 +251,7 @@ geocode <- function(enderecos,
       tipo_resultado = arrow::string(),
       contagem_cnefe = arrow::int32(),
       desvio_metros = arrow::int32(),
+      log_causa_confusao = arrow::boolean(),
       #
       numero_encontrado = arrow::int32(),
       localidade_encontrada = arrow::string(),
@@ -240,12 +315,31 @@ geocode <- function(enderecos,
 
   if (verboso) finish_progress_bar(matched_rows)
 
+  # systime matching 66666 ----------------
+  # timer$mark("Matching")
+
+
   if (verboso) message_preparando_output()
 
-  # add precision column
-  add_precision_col(con, update_tb = 'output_db')
 
 
+  # casos de empate -----------------------------------------------
+
+  empates_resolvidos <- trata_empates_geocode_duckdb(
+    con,
+    resultado_completo,
+    resolver_empates,
+    verboso
+    )
+
+
+
+  # systime resolve empates 66666 ----------------
+  # timer$mark("Resolve empates")
+
+
+  # bring original input back -----------------------------------------------
+
   # output with all original columns
   duckdb::dbWriteTable(con, "input_db", enderecos,
                        temporary = TRUE, overwrite=TRUE)
@@ -253,48 +347,81 @@ geocode <- function(enderecos,
   # DBI::dbWriteTableArrow(con, name = "input_db", enderecos_arrw,
   #                        overwrite = TRUE, temporary = TRUE)
 
+
+  # systime write original input back 66666 ----------------
+  # timer$mark("Write original input back")
+
+
+
+  # add precision column ----------------
+  output_table_to_use <- ifelse(empates_resolvidos==0, 'output_db', 'output_db2')
+  add_precision_col(con, update_tb = output_table_to_use)
+
+  # systime add precision 66666 ----------------
+  # timer$mark("Add precision")
+
+
+
   x_columns <- names(enderecos)
 
-  output_df <- merge_results(
+  output_df <- merge_results_to_input(
     con,
     x='input_db',
-    y='output_db',
+    y= output_table_to_use,
     key_column='tempidgeocodebr',
     select_columns = x_columns,
     resultado_completo = resultado_completo
   )
 
+  # systime merge results 66666 ----------------
+  # timer$mark("Merge results")
+
+
+
+
+
+
+  # systime merge results 66666 ----------------
+  # timer$mark("Merge results")
+
+
   data.table::setDT(output_df)
 
+  # systime resolve empates 66666 ----------------
+  # timer$mark("Resolve empates")
+
+
+  # drop geocodebr temp id column
+  output_df[, tempidgeocodebr := NULL]
+
+
   # Disconnect from DuckDB when done
   duckdb::dbDisconnect(con)
 
 
-  # casos de empate -----------------------------------------------
-  if (nrow(output_df) > n_rows) {
-    output_df <- trata_empates_geocode(output_df, resolver_empates, verboso)
-  }
-
-  # drop geocodebr temp id column
-  output_df[, tempidgeocodebr := NULL]
-
-  if(isFALSE(resultado_completo)){ output_df[, logradouro_encontrado := NULL]}
+  # add H3
 
   # add H3
-  if( !is.null(h3_res) ) {
+  if (!is.null(h3_res)) {
 
-    colname <- paste0(
-      'h3_',
-      formatC(h3_res, width = 2, flag = "0")
-    )
+    for (i in h3_res){
+      colname <- paste0(
+        'h3_',
+        formatC(h3_res, width = 2, flag = "0")
+      )
 
-    output_df[!is.na(lat),
-              {{colname}} := h3r::latLngToCell(lat = lat,
-                                               lng = lon,
-                                               resolution = h3_res)
-              ]
+      output_df[!is.na(lat),
+                {{colname}} := h3r::latLngToCell(lat = lat,
+                                                 lng = lon,
+                                                 resolution = i)]
     }
 
+    # systime add h3 66666 ----------------
+    # timer$mark("Add H3")
+
+  }
+
+
   # convert df to simple feature
   if (isTRUE(resultado_sf)) {
     output_sf <- sfheaders::sf_point(
@@ -305,8 +432,12 @@ geocode <- function(enderecos,
     )
 
     sf::st_crs(output_sf) <- 4674
+
+    # systime convert to sf 66666 ----------------
+    # timer$mark("Convert to sf")
+
     return(output_sf)
   }
 
-  return(output_df)
+  return(output_df[])
 }
