@@ -1,3 +1,42 @@
+# esperado
+5 - deterministico certinho
+7312 - OTIMO antes rua errada no bairro errada, agora pega rua certa no certo
+
+# action
+4398 - ! "RUA  DO BECO 12" continua com match probabilistico
+1690 - ! v2 parece melhor erro na padronizacao???? enderecobr::padronizar_logradouros('RODOVIA  BR 364') 666666 checar como esta no cnfe e nas tabelas
+9577 - ! v2 parece melhor erro na padronizacao???? enderecobr::padronizar_logradouros('RODOVIA  AC 475')
+9470 - padronizacao???? enderecobr::padronizar_logradouros
+
+
+15294 - ! antes pega rua certa no bairro certo (v2 melhor) ????
+
+**** caso 1 - eh melhor o novo
+
+# to ponder
+463 -  1 antes pega rua errada no bairro certo, agora pega rua certa no bairro errado lol (muitos 7)
+5000 - 1 antes pega rua errada no bairro certo, agora pega rua certa no bairro errado lol
+7290 - 1 antes pega rua errada no bairro certo, agora pega rua certa no bairro errado lol (muitos empates)
+8490 - 1 antes pega rua errada no bairro certo, agora pega rua certa no bairro errado lol
+9808 - 1 antes pega rua errada no bairro certo, agora pega rua certa no bairro errado lol
+423 -  1 antes pega rua errada no bairro certo, agora NAO pega rua mas acerta o bairro (desvio grande)
+13814 - 1 antes pega rua certa no cep errado , agora NAO pega rua mas acerta o bairro (desvio 700)
+
+
+5385 - 2 antes pega rua certa no bairro errado, agora NAO pega rua mas acerta o bairro (desvio grande)
+7230 - 2 antes pega rua certa no bairro errado, agora NAO pega rua mas acerta o bairro (desvio 700)
+
+13135 - v2 antes pega rua certa no bairro certo, agora NAO pega rua mas acerta o bairro (desvio 900)
+14063 - nao tem salvacao, v3 melhor pq eh honesto com desvio grande
+15734 - 3 antes pega rua certa no bairro errado, agora NAO pega rua mas acerta o bairro (desvio pequeno anyway)
+13292 - 4 antes pega rua certa no bairro certo, agora NAO pega rua mas acerta o bairro (desvio pequeno anyway)
+10714 - 4 antes pega rua certa no bairro certo, agora NAO pega rua mas acerta o bairro (desvio pequeno anyway)
+9842 - 5 antes rua errada no bairro certo e cep errado, agora pega rua certa no bairro certo e cep errado (dificil)
+
+
+333 - igual "RUA DOM PEDROII" - probabilistico
+4998 - igual "RUA DOM PEDRO II" - deterministico
+
 #' instalar extensoes do duckdb
 #' - spatial - acho q nao vale a pena por agora
 #'
@@ -65,7 +104,7 @@ input_df <- arrow::read_parquet(data_path)
 #   municipio = 'municipio',
 #   estado = 'uf')
 # resolver_empates = T
-
+# h3_res = NULL
 
 # benchmark different approaches ------------------------------------------------------------------
 ncores <- 7
@@ -89,16 +128,29 @@ campos <- geocodebr::definir_campos(
 
 
 bench::mark( iterations = 1,
-  v2 <- geocodebr::geocode(
+  v3 <- geocode(
     enderecos = input_df,
     campos_endereco = campos,
     n_cores = ncores,
-    resultado_completo = T,
+    resultado_completo = F,
     verboso = T,
-    resultado_sf = F,
-    resolver_empates = T
+    resultado_sf = T,
+    resolver_empates = T,
+    h3_res = 9
   )
 )
+
+# expression           min median `itr/sec` mem_alloc `gc/sec` n_itr  n_gc total_time result memory     time       gc
+#       orig         33.5s  33.5s    0.0299    77.1MB    0.239     1     8      33.5s <dt>   <Rprofmem> <bench_tm>
+#       duckrafa     50.2s    0.0199    56.5MB    0.160     1     8      50.2s <dt>   <Rprofmem> <bench_tm>
+
+#         v2_F       25.6s  25.6s    0.0391    64.6MB    0.352     1     9      25.6s <dt>
+#         v3_F       26.2s  26.2s    0.0381      65MB    0.343     1     9      26.2s <dt>
+
+
+    # v2: 729 empates
+# v3: 744 empates
+
 # sequencia de matches
 #   expression    min median `itr/sec` mem_alloc `gc/sec` n_itr  n_gc total_time result memory     time       gc
 #           v2  28.4s  28.4s    0.0352    3.06GB    0.246     1     7
@@ -229,16 +281,17 @@ campos <- geocodebr::definir_campos(
 # n_cores = 7
 # verboso = T
 # cache=T
-# resultado_completo=T
-# resolver_empates = FALSE
+# resultado_completo = F
+# resolver_empates = T
 # resultado_sf = FALSE
+# h3_res =9
 
 dfgeo <- geocodebr::geocode(
     enderecos = input_df,
     campos_endereco = campos,
     n_cores = 7,
     resultado_completo = T,
-    resolver_empates = T,
+    resolver_empates = F,
     verboso = T
   )
 
